==> code-highlight-1.2.3.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.2.3](https://github.com/cycleccc/wangEditor/compare/@wangeditor-next/code-highlight@1.2.2...@wangeditor-next/code-highlight@1.2.3) (2024-08-25)

**Note:** Version bump only for package @wangeditor-next/code-highlight





## [1.2.2](https://github.com/cycleccc/wangEditor/compare/@wangeditor-next/code-highlight@1.2.1...@wangeditor-next/code-highlight@1.2.2) (2024-08-18)

**Note:** Version bump only for package @wangeditor-next/code-highlight





## [1.2.1](https://github.com/cycleccc/wangEditor/compare/@wangeditor-next/code-highlight@1.2.0...@wangeditor-next/code-highlight@1.2.1) (2024-06-22)

**Note:** Version bump only for package @wangeditor-next/code-highlight





# [1.2.0](https://github.com/cycleccc/wangEditor/compare/@wangeditor-next/code-highlight@1.1.0...@wangeditor-next/code-highlight@1.2.0) (2024-05-30)


### Features

* ** issue 5872 :** 文本高亮添加 abap 支持 ([cbb0524](https://github.com/cycleccc/wangEditor/commit/cbb05248968b3a9994979c595c23dbdc7c378b7e))





# 1.1.0 (2024-05-19)


### Bug Fixes

* 代码块 - 增加 lua groovy  语言 ([ef4f62a](https://github.com/cycleccc/wangEditor/commit/ef4f62a876e95995f7c8f6f41d8d44b2505dd5f6))
* 更新各包之间依赖版本 ([75c552c](https://github.com/cycleccc/wangEditor/commit/75c552cc8ed54765bebb86a7ec5329a7fc79e85f))
* 修复 pnpm 安装 @wangeditor/editor 出现警告的问题 ([4087fbe](https://github.com/cycleccc/wangEditor/commit/4087fbee01c76bdd55e747a5e86c5e4a8d6a8353))
* 移除了每个包下的 publishConfig directory 配置 ([16559f0](https://github.com/cycleccc/wangEditor/commit/16559f052545c111318be760e64291a521bdcc65))
* 粘贴 <code> 代码块出错 ([fc44d9f](https://github.com/cycleccc/wangEditor/commit/fc44d9ff36cb9566d9dc5490b4be14f2e5bd3f3c))
* issue 4308 - 自定义字号、字体无法回显 ([ad38b8c](https://github.com/cycleccc/wangEditor/commit/ad38b8ce6dbcff1d65785c8d6701238ad351f562))
* rename es module filename ([1821d4e](https://github.com/cycleccc/wangEditor/commit/1821d4eef49e64efcb41b848849ca7a5e6472044))
* table - elemToHtml ([e36e609](https://github.com/cycleccc/wangEditor/commit/e36e6092ef721723169afc8bf0560a47ac9f4dfc))


### Features

* code highlight ([42b2f8d](https://github.com/cycleccc/wangEditor/commit/42b2f8d192e2433593c11ad0b8424737f6cffb58))
* i18n ([c11b244](https://github.com/cycleccc/wangEditor/commit/c11b2440f91b99d40bca18b675c66a22b6e160c9))
* parse html ([2a5eace](https://github.com/cycleccc/wangEditor/commit/2a5eace00f33cded50b68e8164748ec2480213fd))
* toHtml 机制 ([1c4d872](https://github.com/cycleccc/wangEditor/commit/1c4d8729f84aaab6a448f23064b34a20596305e9))
* upload video ([ac8e6f8](https://github.com/cycleccc/wangEditor/commit/ac8e6f8b5258e593714676a6f6be359ba525833c))





## [1.0.3](https://github.com/cycleccc/wangEditor/compare/@wangeditor/code-highlight@1.0.2...@wangeditor/code-highlight@1.0.3) (2022-09-14)


### Bug Fixes

* 代码块 - 增加 lua groovy  语言 ([ef4f62a](https://github.com/cycleccc/wangEditor/commit/ef4f62a876e95995f7c8f6f41d8d44b2505dd5f6))





## [1.0.2](https://github.com/cycleccc/wangEditor/compare/@wangeditor/code-highlight@1.0.1...@wangeditor/code-highlight@1.0.2) (2022-06-02)


### Bug Fixes

* issue 4308 - 自定义字号、字体无法回显 ([ad38b8c](https://github.com/cycleccc/wangEditor/commit/ad38b8ce6dbcff1d65785c8d6701238ad351f562))





## 1.0.1 (2022-04-18)


### Bug Fixes

* 更新各包之间依赖版本 ([75c552c](https://github.com/cycleccc/wangEditor/commit/75c552cc8ed54765bebb86a7ec5329a7fc79e85f))
* 修复 pnpm 安装 @wangeditor/editor 出现警告的问题 ([4087fbe](https://github.com/cycleccc/wangEditor/commit/4087fbee01c76bdd55e747a5e86c5e4a8d6a8353))
* 移除了每个包下的 publishConfig directory 配置 ([16559f0](https://github.com/cycleccc/wangEditor/commit/16559f052545c111318be760e64291a521bdcc65))
* 粘贴 <code> 代码块出错 ([fc44d9f](https://github.com/cycleccc/wangEditor/commit/fc44d9ff36cb9566d9dc5490b4be14f2e5bd3f3c))
* rename es module filename ([1821d4e](https://github.com/cycleccc/wangEditor/commit/1821d4eef49e64efcb41b848849ca7a5e6472044))
* table - elemToHtml ([e36e609](https://github.com/cycleccc/wangEditor/commit/e36e6092ef721723169afc8bf0560a47ac9f4dfc))


### Features

* code highlight ([42b2f8d](https://github.com/cycleccc/wangEditor/commit/42b2f8d192e2433593c11ad0b8424737f6cffb58))
* i18n ([c11b244](https://github.com/cycleccc/wangEditor/commit/c11b2440f91b99d40bca18b675c66a22b6e160c9))
* parse html ([2a5eace](https://github.com/cycleccc/wangEditor/commit/2a5eace00f33cded50b68e8164748ec2480213fd))
* toHtml 机制 ([1c4d872](https://github.com/cycleccc/wangEditor/commit/1c4d8729f84aaab6a448f23064b34a20596305e9))
* upload video ([ac8e6f8](https://github.com/cycleccc/wangEditor/commit/ac8e6f8b5258e593714676a6f6be359ba525833c))

==> code-highlight-1.3.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# 1.3.0 (2024-05-13)


### Bug Fixes

* 代码块 - 增加 lua groovy  语言 ([ef4f62a](https://github.com/cycleccc/wangEditor/commit/ef4f62a876e95995f7c8f6f41d8d44b2505dd5f6))
* 更新各包之间依赖版本 ([75c552c](https://github.com/cycleccc/wangEditor/commit/75c552cc8ed54765bebb86a7ec5329a7fc79e85f))
* 修复 pnpm 安装 @wangeditor/editor 出现警告的问题 ([4087fbe](https://github.com/cycleccc/wangEditor/commit/4087fbee01c76bdd55e747a5e86c5e4a8d6a8353))
* 移除了每个包下的 publishConfig directory 配置 ([16559f0](https://github.com/cycleccc/wangEditor/commit/16559f052545c111318be760e64291a521bdcc65))
* 粘贴 <code> 代码块出错 ([fc44d9f](https://github.com/cycleccc/wangEditor/commit/fc44d9ff36cb9566d9dc5490b4be14f2e5bd3f3c))
* issue 4308 - 自定义字号、字体无法回显 ([ad38b8c](https://github.com/cycleccc/wangEditor/commit/ad38b8ce6dbcff1d65785c8d6701238ad351f562))
* rename es module filename ([1821d4e](https://github.com/cycleccc/wangEditor/commit/1821d4eef49e64efcb41b848849ca7a5e6472044))
* table - elemToHtml ([e36e609](https://github.com/cycleccc/wangEditor/commit/e36e6092ef721723169afc8bf0560a47ac9f4dfc))


### Features

* code highlight ([42b2f8d](https://github.com/cycleccc/wangEditor/commit/42b2f8d192e2433593c11ad0b8424737f6cffb58))
* i18n ([c11b244](https://github.com/cycleccc/wangEditor/commit/c11b2440f91b99d40bca18b675c66a22b6e160c9))
* parse html ([2a5eace](https://github.com/cycleccc/wangEditor/commit/2a5eace00f33cded50b68e8164748ec2480213fd))
* toHtml 机制 ([1c4d872](https://github.com/cycleccc/wangEditor/commit/1c4d8729f84aaab6a448f23064b34a20596305e9))
* upload video ([ac8e6f8](https://github.com/cycleccc/wangEditor/commit/ac8e6f8b5258e593714676a6f6be359ba525833c))





# 1.2.0 (2024-05-13)


### Bug Fixes

* 代码块 - 增加 lua groovy  语言 ([ef4f62a](https://github.com/cycleccc/wangEditor/commit/ef4f62a876e95995f7c8f6f41d8d44b2505dd5f6))
* 更新各包之间依赖版本 ([75c552c](https://github.com/cycleccc/wangEditor/commit/75c552cc8ed54765bebb86a7ec5329a7fc79e85f))
* 修复 pnpm 安装 @wangeditor/editor 出现警告的问题 ([4087fbe](https://github.com/cycleccc/wangEditor/commit/4087fbee01c76bdd55e747a5e86c5e4a8d6a8353))
* 移除了每个包下的 publishConfig directory 配置 ([16559f0](https://github.com/cycleccc/wangEditor/commit/16559f052545c111318be760e64291a521bdcc65))
* 粘贴 <code> 代码块出错 ([fc44d9f](https://github.com/cycleccc/wangEditor/commit/fc44d9ff36cb9566d9dc5490b4be14f2e5bd3f3c))
* issue 4308 - 自定义字号、字体无法回显 ([ad38b8c](https://github.com/cycleccc/wangEditor/commit/ad38b8ce6dbcff1d65785c8d6701238ad351f562))
* rename es module filename ([1821d4e](https://github.com/cycleccc/wangEditor/commit/1821d4eef49e64efcb41b848849ca7a5e6472044))
* table - elemToHtml ([e36e609](https://github.com/cycleccc/wangEditor/commit/e36e6092ef721723169afc8bf0560a47ac9f4dfc))


### Features

* code highlight ([42b2f8d](https://github.com/cycleccc/wangEditor/commit/42b2f8d192e2433593c11ad0b8424737f6cffb58))
* i18n ([c11b244](https://github.com/cycleccc/wangEditor/commit/c11b2440f91b99d40bca18b675c66a22b6e160c9))
* parse html ([2a5eace](https://github.com/cycleccc/wangEditor/commit/2a5eace00f33cded50b68e8164748ec2480213fd))
* toHtml 机制 ([1c4d872](https://github.com/cycleccc/wangEditor/commit/1c4d8729f84aaab6a448f23064b34a20596305e9))
* upload video ([ac8e6f8](https://github.com/cycleccc/wangEditor/commit/ac8e6f8b5258e593714676a6f6be359ba525833c))





# 1.1.0 (2024-05-13)


### Bug Fixes

* 代码块 - 增加 lua groovy  语言 ([ef4f62a](https://github.com/cycleccc/wangEditor/commit/ef4f62a876e95995f7c8f6f41d8d44b2505dd5f6))
* 更新各包之间依赖版本 ([75c552c](https://github.com/cycleccc/wangEditor/commit/75c552cc8ed54765bebb86a7ec5329a7fc79e85f))
* 修复 pnpm 安装 @wangeditor/editor 出现警告的问题 ([4087fbe](https://github.com/cycleccc/wangEditor/commit/4087fbee01c76bdd55e747a5e86c5e4a8d6a8353))
* 移除了每个包下的 publishConfig directory 配置 ([16559f0](https://github.com/cycleccc/wangEditor/commit/16559f052545c111318be760e64291a521bdcc65))
* 粘贴 <code> 代码块出错 ([fc44d9f](https://github.com/cycleccc/wangEditor/commit/fc44d9ff36cb9566d9dc5490b4be14f2e5bd3f3c))
* issue 4308 - 自定义字号、字体无法回显 ([ad38b8c](https://github.com/cycleccc/wangEditor/commit/ad38b8ce6dbcff1d65785c8d6701238ad351f562))
* rename es module filename ([1821d4e](https://github.com/cycleccc/wangEditor/commit/1821d4eef49e64efcb41b848849ca7a5e6472044))
* table - elemToHtml ([e36e609](https://github.com/cycleccc/wangEditor/commit/e36e6092ef721723169afc8bf0560a47ac9f4dfc))


### Features

* code highlight ([42b2f8d](https://github.com/cycleccc/wangEditor/commit/42b2f8d192e2433593c11ad0b8424737f6cffb58))
* i18n ([c11b244](https://github.com/cycleccc/wangEditor/commit/c11b2440f91b99d40bca18b675c66a22b6e160c9))
* parse html ([2a5eace](https://github.com/cycleccc/wangEditor/commit/2a5eace00f33cded50b68e8164748ec2480213fd))
* toHtml 机制 ([1c4d872](https://github.com/cycleccc/wangEditor/commit/1c4d8729f84aaab6a448f23064b34a20596305e9))
* upload video ([ac8e6f8](https://github.com/cycleccc/wangEditor/commit/ac8e6f8b5258e593714676a6f6be359ba525833c))





## [1.0.3](https://github.com/wangeditor-team/wangEditor/compare/@wangeditor/code-highlight@1.0.2...@wangeditor/code-highlight@1.0.3) (2022-09-14)


### Bug Fixes

* 代码块 - 增加 lua groovy  语言 ([ef4f62a](https://github.com/wangeditor-team/wangEditor/commit/ef4f62a876e95995f7c8f6f41d8d44b2505dd5f6))





## [1.0.2](https://github.com/wangeditor-team/wangEditor/compare/@wangeditor/code-highlight@1.0.1...@wangeditor/code-highlight@1.0.2) (2022-06-02)


### Bug Fixes

* issue 4308 - 自定义字号、字体无法回显 ([ad38b8c](https://github.com/wangeditor-team/wangEditor/commit/ad38b8ce6dbcff1d65785c8d6701238ad351f562))





## 1.0.1 (2022-04-18)


### Bug Fixes

* 更新各包之间依赖版本 ([75c552c](https://github.com/wangeditor-team/wangEditor/commit/75c552cc8ed54765bebb86a7ec5329a7fc79e85f))
* 修复 pnpm 安装 @wangeditor/editor 出现警告的问题 ([4087fbe](https://github.com/wangeditor-team/wangEditor/commit/4087fbee01c76bdd55e747a5e86c5e4a8d6a8353))
* 移除了每个包下的 publishConfig directory 配置 ([16559f0](https://github.com/wangeditor-team/wangEditor/commit/16559f052545c111318be760e64291a521bdcc65))
* 粘贴 <code> 代码块出错 ([fc44d9f](https://github.com/wangeditor-team/wangEditor/commit/fc44d9ff36cb9566d9dc5490b4be14f2e5bd3f3c))
* rename es module filename ([1821d4e](https://github.com/wangeditor-team/wangEditor/commit/1821d4eef49e64efcb41b848849ca7a5e6472044))
* table - elemToHtml ([e36e609](https://github.com/wangeditor-team/wangEditor/commit/e36e6092ef721723169afc8bf0560a47ac9f4dfc))


### Features

* code highlight ([42b2f8d](https://github.com/wangeditor-team/wangEditor/commit/42b2f8d192e2433593c11ad0b8424737f6cffb58))
* i18n ([c11b244](https://github.com/wangeditor-team/wangEditor/commit/c11b2440f91b99d40bca18b675c66a22b6e160c9))
* parse html ([2a5eace](https://github.com/wangeditor-team/wangEditor/commit/2a5eace00f33cded50b68e8164748ec2480213fd))
* toHtml 机制 ([1c4d872](https://github.com/wangeditor-team/wangEditor/commit/1c4d8729f84aaab6a448f23064b34a20596305e9))
* upload video ([ac8e6f8](https://github.com/wangeditor-team/wangEditor/commit/ac8e6f8b5258e593714676a6f6be359ba525833c))
